# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .projection_rule import ProjectionRule
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NameListRule(ProjectionRule):
    """
    The name list rule which defines how fields are projected. For example, this may be all fields begining with STR.
    """

    #: A constant which can be used with the matching_strategy property of a NameListRule.
    #: This constant has a value of "NAME_OR_TAGS"
    MATCHING_STRATEGY_NAME_OR_TAGS = "NAME_OR_TAGS"

    #: A constant which can be used with the matching_strategy property of a NameListRule.
    #: This constant has a value of "TAGS_ONLY"
    MATCHING_STRATEGY_TAGS_ONLY = "TAGS_ONLY"

    #: A constant which can be used with the matching_strategy property of a NameListRule.
    #: This constant has a value of "NAME_ONLY"
    MATCHING_STRATEGY_NAME_ONLY = "NAME_ONLY"

    #: A constant which can be used with the rule_type property of a NameListRule.
    #: This constant has a value of "INCLUDE"
    RULE_TYPE_INCLUDE = "INCLUDE"

    #: A constant which can be used with the rule_type property of a NameListRule.
    #: This constant has a value of "EXCLUDE"
    RULE_TYPE_EXCLUDE = "EXCLUDE"

    def __init__(self, **kwargs):
        """
        Initializes a new NameListRule object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.NameListRule.model_type` attribute
        of this class is ``NAME_LIST_RULE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this NameListRule.
            Allowed values for this property are: "NAME_PATTERN_RULE", "TYPE_LIST_RULE", "NAME_LIST_RULE", "TYPED_NAME_PATTERN_RULE", "RENAME_RULE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param key:
            The value to assign to the key property of this NameListRule.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this NameListRule.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this NameListRule.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param is_java_regex_syntax:
            The value to assign to the is_java_regex_syntax property of this NameListRule.
        :type is_java_regex_syntax: bool

        :param config_values:
            The value to assign to the config_values property of this NameListRule.
        :type config_values: oci.data_integration.models.ConfigValues

        :param object_status:
            The value to assign to the object_status property of this NameListRule.
        :type object_status: int

        :param description:
            The value to assign to the description property of this NameListRule.
        :type description: str

        :param is_skip_remaining_rules_on_match:
            The value to assign to the is_skip_remaining_rules_on_match property of this NameListRule.
        :type is_skip_remaining_rules_on_match: bool

        :param scope:
            The value to assign to the scope property of this NameListRule.
        :type scope: object

        :param is_cascade:
            The value to assign to the is_cascade property of this NameListRule.
        :type is_cascade: bool

        :param matching_strategy:
            The value to assign to the matching_strategy property of this NameListRule.
            Allowed values for this property are: "NAME_OR_TAGS", "TAGS_ONLY", "NAME_ONLY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type matching_strategy: str

        :param is_case_sensitive:
            The value to assign to the is_case_sensitive property of this NameListRule.
        :type is_case_sensitive: bool

        :param rule_type:
            The value to assign to the rule_type property of this NameListRule.
            Allowed values for this property are: "INCLUDE", "EXCLUDE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type rule_type: str

        :param names:
            The value to assign to the names property of this NameListRule.
        :type names: list[str]

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'is_java_regex_syntax': 'bool',
            'config_values': 'ConfigValues',
            'object_status': 'int',
            'description': 'str',
            'is_skip_remaining_rules_on_match': 'bool',
            'scope': 'object',
            'is_cascade': 'bool',
            'matching_strategy': 'str',
            'is_case_sensitive': 'bool',
            'rule_type': 'str',
            'names': 'list[str]'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'is_java_regex_syntax': 'isJavaRegexSyntax',
            'config_values': 'configValues',
            'object_status': 'objectStatus',
            'description': 'description',
            'is_skip_remaining_rules_on_match': 'isSkipRemainingRulesOnMatch',
            'scope': 'scope',
            'is_cascade': 'isCascade',
            'matching_strategy': 'matchingStrategy',
            'is_case_sensitive': 'isCaseSensitive',
            'rule_type': 'ruleType',
            'names': 'names'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._is_java_regex_syntax = None
        self._config_values = None
        self._object_status = None
        self._description = None
        self._is_skip_remaining_rules_on_match = None
        self._scope = None
        self._is_cascade = None
        self._matching_strategy = None
        self._is_case_sensitive = None
        self._rule_type = None
        self._names = None
        self._model_type = 'NAME_LIST_RULE'

    @property
    def is_skip_remaining_rules_on_match(self):
        """
        Gets the is_skip_remaining_rules_on_match of this NameListRule.
        Specifies whether to skip remaining rules when a match is found.


        :return: The is_skip_remaining_rules_on_match of this NameListRule.
        :rtype: bool
        """
        return self._is_skip_remaining_rules_on_match

    @is_skip_remaining_rules_on_match.setter
    def is_skip_remaining_rules_on_match(self, is_skip_remaining_rules_on_match):
        """
        Sets the is_skip_remaining_rules_on_match of this NameListRule.
        Specifies whether to skip remaining rules when a match is found.


        :param is_skip_remaining_rules_on_match: The is_skip_remaining_rules_on_match of this NameListRule.
        :type: bool
        """
        self._is_skip_remaining_rules_on_match = is_skip_remaining_rules_on_match

    @property
    def scope(self):
        """
        Gets the scope of this NameListRule.
        Reference to a typed object. This can be either a key value to an object within the document, a shall referenced to a `TypedObject`, or a full `TypedObject` definition.


        :return: The scope of this NameListRule.
        :rtype: object
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """
        Sets the scope of this NameListRule.
        Reference to a typed object. This can be either a key value to an object within the document, a shall referenced to a `TypedObject`, or a full `TypedObject` definition.


        :param scope: The scope of this NameListRule.
        :type: object
        """
        self._scope = scope

    @property
    def is_cascade(self):
        """
        Gets the is_cascade of this NameListRule.
        Specifies whether to cascade or not.


        :return: The is_cascade of this NameListRule.
        :rtype: bool
        """
        return self._is_cascade

    @is_cascade.setter
    def is_cascade(self, is_cascade):
        """
        Sets the is_cascade of this NameListRule.
        Specifies whether to cascade or not.


        :param is_cascade: The is_cascade of this NameListRule.
        :type: bool
        """
        self._is_cascade = is_cascade

    @property
    def matching_strategy(self):
        """
        Gets the matching_strategy of this NameListRule.
        The pattern matching strategy.

        Allowed values for this property are: "NAME_OR_TAGS", "TAGS_ONLY", "NAME_ONLY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The matching_strategy of this NameListRule.
        :rtype: str
        """
        return self._matching_strategy

    @matching_strategy.setter
    def matching_strategy(self, matching_strategy):
        """
        Sets the matching_strategy of this NameListRule.
        The pattern matching strategy.


        :param matching_strategy: The matching_strategy of this NameListRule.
        :type: str
        """
        allowed_values = ["NAME_OR_TAGS", "TAGS_ONLY", "NAME_ONLY"]
        if not value_allowed_none_or_none_sentinel(matching_strategy, allowed_values):
            matching_strategy = 'UNKNOWN_ENUM_VALUE'
        self._matching_strategy = matching_strategy

    @property
    def is_case_sensitive(self):
        """
        Gets the is_case_sensitive of this NameListRule.
        Specifies if the rule is case sensitive.


        :return: The is_case_sensitive of this NameListRule.
        :rtype: bool
        """
        return self._is_case_sensitive

    @is_case_sensitive.setter
    def is_case_sensitive(self, is_case_sensitive):
        """
        Sets the is_case_sensitive of this NameListRule.
        Specifies if the rule is case sensitive.


        :param is_case_sensitive: The is_case_sensitive of this NameListRule.
        :type: bool
        """
        self._is_case_sensitive = is_case_sensitive

    @property
    def rule_type(self):
        """
        Gets the rule_type of this NameListRule.
        The rule type.

        Allowed values for this property are: "INCLUDE", "EXCLUDE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The rule_type of this NameListRule.
        :rtype: str
        """
        return self._rule_type

    @rule_type.setter
    def rule_type(self, rule_type):
        """
        Sets the rule_type of this NameListRule.
        The rule type.


        :param rule_type: The rule_type of this NameListRule.
        :type: str
        """
        allowed_values = ["INCLUDE", "EXCLUDE"]
        if not value_allowed_none_or_none_sentinel(rule_type, allowed_values):
            rule_type = 'UNKNOWN_ENUM_VALUE'
        self._rule_type = rule_type

    @property
    def names(self):
        """
        Gets the names of this NameListRule.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The names of this NameListRule.
        :rtype: list[str]
        """
        return self._names

    @names.setter
    def names(self, names):
        """
        Sets the names of this NameListRule.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param names: The names of this NameListRule.
        :type: list[str]
        """
        self._names = names

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Topology(object):
    """
    Defines the representation of a virtual network topology.
    """

    #: A constant which can be used with the type property of a Topology.
    #: This constant has a value of "NETWORKING"
    TYPE_NETWORKING = "NETWORKING"

    #: A constant which can be used with the type property of a Topology.
    #: This constant has a value of "VCN"
    TYPE_VCN = "VCN"

    def __init__(self, **kwargs):
        """
        Initializes a new Topology object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.core.models.VcnTopology`
        * :class:`~oci.core.models.NetworkingTopology`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this Topology.
            Allowed values for this property are: "NETWORKING", "VCN"
        :type type: str

        :param entities:
            The value to assign to the entities property of this Topology.
        :type entities: list[object]

        :param relationships:
            The value to assign to the relationships property of this Topology.
        :type relationships: list[oci.core.models.TopologyEntityRelationship]

        :param time_created:
            The value to assign to the time_created property of this Topology.
        :type time_created: datetime

        """
        self.swagger_types = {
            'type': 'str',
            'entities': 'list[object]',
            'relationships': 'list[TopologyEntityRelationship]',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'type': 'type',
            'entities': 'entities',
            'relationships': 'relationships',
            'time_created': 'timeCreated'
        }

        self._type = None
        self._entities = None
        self._relationships = None
        self._time_created = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['type']

        if type == 'VCN':
            return 'VcnTopology'

        if type == 'NETWORKING':
            return 'NetworkingTopology'
        else:
            return 'Topology'

    @property
    def type(self):
        """
        **[Required]** Gets the type of this Topology.
        Type of the topology object.

        Allowed values for this property are: "NETWORKING", "VCN"


        :return: The type of this Topology.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Topology.
        Type of the topology object.


        :param type: The type of this Topology.
        :type: str
        """
        allowed_values = ["NETWORKING", "VCN"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            raise ValueError(
                "Invalid value for `type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def entities(self):
        """
        **[Required]** Gets the entities of this Topology.
        Lists entities comprising the virtual network topology.


        :return: The entities of this Topology.
        :rtype: list[object]
        """
        return self._entities

    @entities.setter
    def entities(self, entities):
        """
        Sets the entities of this Topology.
        Lists entities comprising the virtual network topology.


        :param entities: The entities of this Topology.
        :type: list[object]
        """
        self._entities = entities

    @property
    def relationships(self):
        """
        **[Required]** Gets the relationships of this Topology.
        Lists relationships between entities in the virtual network topology.


        :return: The relationships of this Topology.
        :rtype: list[oci.core.models.TopologyEntityRelationship]
        """
        return self._relationships

    @relationships.setter
    def relationships(self, relationships):
        """
        Sets the relationships of this Topology.
        Lists relationships between entities in the virtual network topology.


        :param relationships: The relationships of this Topology.
        :type: list[oci.core.models.TopologyEntityRelationship]
        """
        self._relationships = relationships

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this Topology.
        Records when the virtual network topology was created, in `RFC3339`__ format for date and time.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this Topology.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Topology.
        Records when the virtual network topology was created, in `RFC3339`__ format for date and time.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this Topology.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UiParserTestMetadata(object):
    """
    UiParserTestMetadata
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UiParserTestMetadata object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param last_modified_time:
            The value to assign to the last_modified_time property of this UiParserTestMetadata.
        :type last_modified_time: str

        :param log_file_name:
            The value to assign to the log_file_name property of this UiParserTestMetadata.
        :type log_file_name: str

        :param time_zone:
            The value to assign to the time_zone property of this UiParserTestMetadata.
        :type time_zone: datetime

        """
        self.swagger_types = {
            'last_modified_time': 'str',
            'log_file_name': 'str',
            'time_zone': 'datetime'
        }

        self.attribute_map = {
            'last_modified_time': 'lastModifiedTime',
            'log_file_name': 'logFileName',
            'time_zone': 'timeZone'
        }

        self._last_modified_time = None
        self._log_file_name = None
        self._time_zone = None

    @property
    def last_modified_time(self):
        """
        Gets the last_modified_time of this UiParserTestMetadata.
        The last modified time.


        :return: The last_modified_time of this UiParserTestMetadata.
        :rtype: str
        """
        return self._last_modified_time

    @last_modified_time.setter
    def last_modified_time(self, last_modified_time):
        """
        Sets the last_modified_time of this UiParserTestMetadata.
        The last modified time.


        :param last_modified_time: The last_modified_time of this UiParserTestMetadata.
        :type: str
        """
        self._last_modified_time = last_modified_time

    @property
    def log_file_name(self):
        """
        Gets the log_file_name of this UiParserTestMetadata.
        The log file name.


        :return: The log_file_name of this UiParserTestMetadata.
        :rtype: str
        """
        return self._log_file_name

    @log_file_name.setter
    def log_file_name(self, log_file_name):
        """
        Sets the log_file_name of this UiParserTestMetadata.
        The log file name.


        :param log_file_name: The log_file_name of this UiParserTestMetadata.
        :type: str
        """
        self._log_file_name = log_file_name

    @property
    def time_zone(self):
        """
        Gets the time_zone of this UiParserTestMetadata.
        The time zone.


        :return: The time_zone of this UiParserTestMetadata.
        :rtype: datetime
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this UiParserTestMetadata.
        The time zone.


        :param time_zone: The time_zone of this UiParserTestMetadata.
        :type: datetime
        """
        self._time_zone = time_zone

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AttachCatalogPrivateEndpointDetails(object):
    """
    Information about the attaching the private endpoint resource to a catalog
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AttachCatalogPrivateEndpointDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param catalog_private_endpoint_id:
            The value to assign to the catalog_private_endpoint_id property of this AttachCatalogPrivateEndpointDetails.
        :type catalog_private_endpoint_id: str

        """
        self.swagger_types = {
            'catalog_private_endpoint_id': 'str'
        }

        self.attribute_map = {
            'catalog_private_endpoint_id': 'catalogPrivateEndpointId'
        }

        self._catalog_private_endpoint_id = None

    @property
    def catalog_private_endpoint_id(self):
        """
        **[Required]** Gets the catalog_private_endpoint_id of this AttachCatalogPrivateEndpointDetails.
        The identifier of the private endpoint to be attached to the catalog resource.


        :return: The catalog_private_endpoint_id of this AttachCatalogPrivateEndpointDetails.
        :rtype: str
        """
        return self._catalog_private_endpoint_id

    @catalog_private_endpoint_id.setter
    def catalog_private_endpoint_id(self, catalog_private_endpoint_id):
        """
        Sets the catalog_private_endpoint_id of this AttachCatalogPrivateEndpointDetails.
        The identifier of the private endpoint to be attached to the catalog resource.


        :param catalog_private_endpoint_id: The catalog_private_endpoint_id of this AttachCatalogPrivateEndpointDetails.
        :type: str
        """
        self._catalog_private_endpoint_id = catalog_private_endpoint_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApiSpecificationRouteRequestPolicies(object):
    """
    Behavior applied to any requests received by the API on this route.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ApiSpecificationRouteRequestPolicies object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param authorization:
            The value to assign to the authorization property of this ApiSpecificationRouteRequestPolicies.
        :type authorization: oci.apigateway.models.RouteAuthorizationPolicy

        :param cors:
            The value to assign to the cors property of this ApiSpecificationRouteRequestPolicies.
        :type cors: oci.apigateway.models.CorsPolicy

        :param query_parameter_validations:
            The value to assign to the query_parameter_validations property of this ApiSpecificationRouteRequestPolicies.
        :type query_parameter_validations: oci.apigateway.models.QueryParameterValidationRequestPolicy

        :param header_validations:
            The value to assign to the header_validations property of this ApiSpecificationRouteRequestPolicies.
        :type header_validations: oci.apigateway.models.HeaderValidationRequestPolicy

        :param body_validation:
            The value to assign to the body_validation property of this ApiSpecificationRouteRequestPolicies.
        :type body_validation: oci.apigateway.models.BodyValidationRequestPolicy

        :param header_transformations:
            The value to assign to the header_transformations property of this ApiSpecificationRouteRequestPolicies.
        :type header_transformations: oci.apigateway.models.HeaderTransformationPolicy

        :param query_parameter_transformations:
            The value to assign to the query_parameter_transformations property of this ApiSpecificationRouteRequestPolicies.
        :type query_parameter_transformations: oci.apigateway.models.QueryParameterTransformationPolicy

        :param response_cache_lookup:
            The value to assign to the response_cache_lookup property of this ApiSpecificationRouteRequestPolicies.
        :type response_cache_lookup: oci.apigateway.models.ResponseCacheLookupPolicy

        """
        self.swagger_types = {
            'authorization': 'RouteAuthorizationPolicy',
            'cors': 'CorsPolicy',
            'query_parameter_validations': 'QueryParameterValidationRequestPolicy',
            'header_validations': 'HeaderValidationRequestPolicy',
            'body_validation': 'BodyValidationRequestPolicy',
            'header_transformations': 'HeaderTransformationPolicy',
            'query_parameter_transformations': 'QueryParameterTransformationPolicy',
            'response_cache_lookup': 'ResponseCacheLookupPolicy'
        }

        self.attribute_map = {
            'authorization': 'authorization',
            'cors': 'cors',
            'query_parameter_validations': 'queryParameterValidations',
            'header_validations': 'headerValidations',
            'body_validation': 'bodyValidation',
            'header_transformations': 'headerTransformations',
            'query_parameter_transformations': 'queryParameterTransformations',
            'response_cache_lookup': 'responseCacheLookup'
        }

        self._authorization = None
        self._cors = None
        self._query_parameter_validations = None
        self._header_validations = None
        self._body_validation = None
        self._header_transformations = None
        self._query_parameter_transformations = None
        self._response_cache_lookup = None

    @property
    def authorization(self):
        """
        Gets the authorization of this ApiSpecificationRouteRequestPolicies.

        :return: The authorization of this ApiSpecificationRouteRequestPolicies.
        :rtype: oci.apigateway.models.RouteAuthorizationPolicy
        """
        return self._authorization

    @authorization.setter
    def authorization(self, authorization):
        """
        Sets the authorization of this ApiSpecificationRouteRequestPolicies.

        :param authorization: The authorization of this ApiSpecificationRouteRequestPolicies.
        :type: oci.apigateway.models.RouteAuthorizationPolicy
        """
        self._authorization = authorization

    @property
    def cors(self):
        """
        Gets the cors of this ApiSpecificationRouteRequestPolicies.

        :return: The cors of this ApiSpecificationRouteRequestPolicies.
        :rtype: oci.apigateway.models.CorsPolicy
        """
        return self._cors

    @cors.setter
    def cors(self, cors):
        """
        Sets the cors of this ApiSpecificationRouteRequestPolicies.

        :param cors: The cors of this ApiSpecificationRouteRequestPolicies.
        :type: oci.apigateway.models.CorsPolicy
        """
        self._cors = cors

    @property
    def query_parameter_validations(self):
        """
        Gets the query_parameter_validations of this ApiSpecificationRouteRequestPolicies.

        :return: The query_parameter_validations of this ApiSpecificationRouteRequestPolicies.
        :rtype: oci.apigateway.models.QueryParameterValidationRequestPolicy
        """
        return self._query_parameter_validations

    @query_parameter_validations.setter
    def query_parameter_validations(self, query_parameter_validations):
        """
        Sets the query_parameter_validations of this ApiSpecificationRouteRequestPolicies.

        :param query_parameter_validations: The query_parameter_validations of this ApiSpecificationRouteRequestPolicies.
        :type: oci.apigateway.models.QueryParameterValidationRequestPolicy
        """
        self._query_parameter_validations = query_parameter_validations

    @property
    def header_validations(self):
        """
        Gets the header_validations of this ApiSpecificationRouteRequestPolicies.

        :return: The header_validations of this ApiSpecificationRouteRequestPolicies.
        :rtype: oci.apigateway.models.HeaderValidationRequestPolicy
        """
        return self._header_validations

    @header_validations.setter
    def header_validations(self, header_validations):
        """
        Sets the header_validations of this ApiSpecificationRouteRequestPolicies.

        :param header_validations: The header_validations of this ApiSpecificationRouteRequestPolicies.
        :type: oci.apigateway.models.HeaderValidationRequestPolicy
        """
        self._header_validations = header_validations

    @property
    def body_validation(self):
        """
        Gets the body_validation of this ApiSpecificationRouteRequestPolicies.

        :return: The body_validation of this ApiSpecificationRouteRequestPolicies.
        :rtype: oci.apigateway.models.BodyValidationRequestPolicy
        """
        return self._body_validation

    @body_validation.setter
    def body_validation(self, body_validation):
        """
        Sets the body_validation of this ApiSpecificationRouteRequestPolicies.

        :param body_validation: The body_validation of this ApiSpecificationRouteRequestPolicies.
        :type: oci.apigateway.models.BodyValidationRequestPolicy
        """
        self._body_validation = body_validation

    @property
    def header_transformations(self):
        """
        Gets the header_transformations of this ApiSpecificationRouteRequestPolicies.

        :return: The header_transformations of this ApiSpecificationRouteRequestPolicies.
        :rtype: oci.apigateway.models.HeaderTransformationPolicy
        """
        return self._header_transformations

    @header_transformations.setter
    def header_transformations(self, header_transformations):
        """
        Sets the header_transformations of this ApiSpecificationRouteRequestPolicies.

        :param header_transformations: The header_transformations of this ApiSpecificationRouteRequestPolicies.
        :type: oci.apigateway.models.HeaderTransformationPolicy
        """
        self._header_transformations = header_transformations

    @property
    def query_parameter_transformations(self):
        """
        Gets the query_parameter_transformations of this ApiSpecificationRouteRequestPolicies.

        :return: The query_parameter_transformations of this ApiSpecificationRouteRequestPolicies.
        :rtype: oci.apigateway.models.QueryParameterTransformationPolicy
        """
        return self._query_parameter_transformations

    @query_parameter_transformations.setter
    def query_parameter_transformations(self, query_parameter_transformations):
        """
        Sets the query_parameter_transformations of this ApiSpecificationRouteRequestPolicies.

        :param query_parameter_transformations: The query_parameter_transformations of this ApiSpecificationRouteRequestPolicies.
        :type: oci.apigateway.models.QueryParameterTransformationPolicy
        """
        self._query_parameter_transformations = query_parameter_transformations

    @property
    def response_cache_lookup(self):
        """
        Gets the response_cache_lookup of this ApiSpecificationRouteRequestPolicies.

        :return: The response_cache_lookup of this ApiSpecificationRouteRequestPolicies.
        :rtype: oci.apigateway.models.ResponseCacheLookupPolicy
        """
        return self._response_cache_lookup

    @response_cache_lookup.setter
    def response_cache_lookup(self, response_cache_lookup):
        """
        Sets the response_cache_lookup of this ApiSpecificationRouteRequestPolicies.

        :param response_cache_lookup: The response_cache_lookup of this ApiSpecificationRouteRequestPolicies.
        :type: oci.apigateway.models.ResponseCacheLookupPolicy
        """
        self._response_cache_lookup = response_cache_lookup

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class EnrichedEntity(object):
    """
    This is used to specify runtime parameters for data entities such as files that need both the data entity and the format.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new EnrichedEntity object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity:
            The value to assign to the entity property of this EnrichedEntity.
        :type entity: oci.data_integration.models.DataEntity

        :param data_format:
            The value to assign to the data_format property of this EnrichedEntity.
        :type data_format: oci.data_integration.models.DataFormat

        :param model_type:
            The value to assign to the model_type property of this EnrichedEntity.
        :type model_type: str

        :param parent_ref:
            The value to assign to the parent_ref property of this EnrichedEntity.
        :type parent_ref: oci.data_integration.models.ParentReference

        """
        self.swagger_types = {
            'entity': 'DataEntity',
            'data_format': 'DataFormat',
            'model_type': 'str',
            'parent_ref': 'ParentReference'
        }

        self.attribute_map = {
            'entity': 'entity',
            'data_format': 'dataFormat',
            'model_type': 'modelType',
            'parent_ref': 'parentRef'
        }

        self._entity = None
        self._data_format = None
        self._model_type = None
        self._parent_ref = None

    @property
    def entity(self):
        """
        Gets the entity of this EnrichedEntity.

        :return: The entity of this EnrichedEntity.
        :rtype: oci.data_integration.models.DataEntity
        """
        return self._entity

    @entity.setter
    def entity(self, entity):
        """
        Sets the entity of this EnrichedEntity.

        :param entity: The entity of this EnrichedEntity.
        :type: oci.data_integration.models.DataEntity
        """
        self._entity = entity

    @property
    def data_format(self):
        """
        Gets the data_format of this EnrichedEntity.

        :return: The data_format of this EnrichedEntity.
        :rtype: oci.data_integration.models.DataFormat
        """
        return self._data_format

    @data_format.setter
    def data_format(self, data_format):
        """
        Sets the data_format of this EnrichedEntity.

        :param data_format: The data_format of this EnrichedEntity.
        :type: oci.data_integration.models.DataFormat
        """
        self._data_format = data_format

    @property
    def model_type(self):
        """
        Gets the model_type of this EnrichedEntity.
        The model type for the entity which is referenced.


        :return: The model_type of this EnrichedEntity.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this EnrichedEntity.
        The model type for the entity which is referenced.


        :param model_type: The model_type of this EnrichedEntity.
        :type: str
        """
        self._model_type = model_type

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this EnrichedEntity.

        :return: The parent_ref of this EnrichedEntity.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this EnrichedEntity.

        :param parent_ref: The parent_ref of this EnrichedEntity.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ImportDataAssetDetails(object):
    """
    Specifies the file contents to be imported.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ImportDataAssetDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param import_file_contents:
            The value to assign to the import_file_contents property of this ImportDataAssetDetails.
        :type import_file_contents: str

        """
        self.swagger_types = {
            'import_file_contents': 'str'
        }

        self.attribute_map = {
            'import_file_contents': 'importFileContents'
        }

        self._import_file_contents = None

    @property
    def import_file_contents(self):
        """
        **[Required]** Gets the import_file_contents of this ImportDataAssetDetails.
        The file contents to be imported. File size not to exceed 10 MB.


        :return: The import_file_contents of this ImportDataAssetDetails.
        :rtype: str
        """
        return self._import_file_contents

    @import_file_contents.setter
    def import_file_contents(self, import_file_contents):
        """
        Sets the import_file_contents of this ImportDataAssetDetails.
        The file contents to be imported. File size not to exceed 10 MB.


        :param import_file_contents: The import_file_contents of this ImportDataAssetDetails.
        :type: str
        """
        self._import_file_contents = import_file_contents

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DbHomeFromAgentResourceId(object):
    """
    DbHomeFromAgentResourceId model.
    """

    #: A constant which can be used with the lifecycle_state property of a DbHomeFromAgentResourceId.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a DbHomeFromAgentResourceId.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a DbHomeFromAgentResourceId.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a DbHomeFromAgentResourceId.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a DbHomeFromAgentResourceId.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a DbHomeFromAgentResourceId.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new DbHomeFromAgentResourceId object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this DbHomeFromAgentResourceId.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DbHomeFromAgentResourceId.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this DbHomeFromAgentResourceId.
        :type display_name: str

        :param last_patch_history_entry_id:
            The value to assign to the last_patch_history_entry_id property of this DbHomeFromAgentResourceId.
        :type last_patch_history_entry_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DbHomeFromAgentResourceId.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED"
        :type lifecycle_state: str

        :param db_system_id:
            The value to assign to the db_system_id property of this DbHomeFromAgentResourceId.
        :type db_system_id: str

        :param vm_cluster_id:
            The value to assign to the vm_cluster_id property of this DbHomeFromAgentResourceId.
        :type vm_cluster_id: str

        :param db_version:
            The value to assign to the db_version property of this DbHomeFromAgentResourceId.
        :type db_version: str

        :param db_home_location:
            The value to assign to the db_home_location property of this DbHomeFromAgentResourceId.
        :type db_home_location: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this DbHomeFromAgentResourceId.
        :type lifecycle_details: str

        :param time_created:
            The value to assign to the time_created property of this DbHomeFromAgentResourceId.
        :type time_created: datetime

        :param kms_key_id:
            The value to assign to the kms_key_id property of this DbHomeFromAgentResourceId.
        :type kms_key_id: str

        :param one_off_patches:
            The value to assign to the one_off_patches property of this DbHomeFromAgentResourceId.
        :type one_off_patches: list[str]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DbHomeFromAgentResourceId.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DbHomeFromAgentResourceId.
        :type defined_tags: dict(str, dict(str, object))

        :param database_software_image_id:
            The value to assign to the database_software_image_id property of this DbHomeFromAgentResourceId.
        :type database_software_image_id: str

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'last_patch_history_entry_id': 'str',
            'lifecycle_state': 'str',
            'db_system_id': 'str',
            'vm_cluster_id': 'str',
            'db_version': 'str',
            'db_home_location': 'str',
            'lifecycle_details': 'str',
            'time_created': 'datetime',
            'kms_key_id': 'str',
            'one_off_patches': 'list[str]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'database_software_image_id': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'last_patch_history_entry_id': 'lastPatchHistoryEntryId',
            'lifecycle_state': 'lifecycleState',
            'db_system_id': 'dbSystemId',
            'vm_cluster_id': 'vmClusterId',
            'db_version': 'dbVersion',
            'db_home_location': 'dbHomeLocation',
            'lifecycle_details': 'lifecycleDetails',
            'time_created': 'timeCreated',
            'kms_key_id': 'kmsKeyId',
            'one_off_patches': 'oneOffPatches',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'database_software_image_id': 'databaseSoftwareImageId'
        }

        self._id = None
        self._compartment_id = None
        self._display_name = None
        self._last_patch_history_entry_id = None
        self._lifecycle_state = None
        self._db_system_id = None
        self._vm_cluster_id = None
        self._db_version = None
        self._db_home_location = None
        self._lifecycle_details = None
        self._time_created = None
        self._kms_key_id = None
        self._one_off_patches = None
        self._freeform_tags = None
        self._defined_tags = None
        self._database_software_image_id = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DbHomeFromAgentResourceId.
        The `OCID`__ of the Database Home.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this DbHomeFromAgentResourceId.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DbHomeFromAgentResourceId.
        The `OCID`__ of the Database Home.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this DbHomeFromAgentResourceId.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this DbHomeFromAgentResourceId.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this DbHomeFromAgentResourceId.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DbHomeFromAgentResourceId.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this DbHomeFromAgentResourceId.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this DbHomeFromAgentResourceId.
        The user-provided name for the Database Home. The name does not need to be unique.


        :return: The display_name of this DbHomeFromAgentResourceId.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DbHomeFromAgentResourceId.
        The user-provided name for the Database Home. The name does not need to be unique.


        :param display_name: The display_name of this DbHomeFromAgentResourceId.
        :type: str
        """
        self._display_name = display_name

    @property
    def last_patch_history_entry_id(self):
        """
        Gets the last_patch_history_entry_id of this DbHomeFromAgentResourceId.
        The `OCID`__ of the last patch history. This value is updated as soon as a patch operation is started.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The last_patch_history_entry_id of this DbHomeFromAgentResourceId.
        :rtype: str
        """
        return self._last_patch_history_entry_id

    @last_patch_history_entry_id.setter
    def last_patch_history_entry_id(self, last_patch_history_entry_id):
        """
        Sets the last_patch_history_entry_id of this DbHomeFromAgentResourceId.
        The `OCID`__ of the last patch history. This value is updated as soon as a patch operation is started.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param last_patch_history_entry_id: The last_patch_history_entry_id of this DbHomeFromAgentResourceId.
        :type: str
        """
        self._last_patch_history_entry_id = last_patch_history_entry_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this DbHomeFromAgentResourceId.
        The current state of the Database Home.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED"


        :return: The lifecycle_state of this DbHomeFromAgentResourceId.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DbHomeFromAgentResourceId.
        The current state of the Database Home.


        :param lifecycle_state: The lifecycle_state of this DbHomeFromAgentResourceId.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            raise ValueError(
                "Invalid value for `lifecycle_state`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._lifecycle_state = lifecycle_state

    @property
    def db_system_id(self):
        """
        Gets the db_system_id of this DbHomeFromAgentResourceId.
        The `OCID`__ of the DB system.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The db_system_id of this DbHomeFromAgentResourceId.
        :rtype: str
        """
        return self._db_system_id

    @db_system_id.setter
    def db_system_id(self, db_system_id):
        """
        Sets the db_system_id of this DbHomeFromAgentResourceId.
        The `OCID`__ of the DB system.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param db_system_id: The db_system_id of this DbHomeFromAgentResourceId.
        :type: str
        """
        self._db_system_id = db_system_id

    @property
    def vm_cluster_id(self):
        """
        Gets the vm_cluster_id of this DbHomeFromAgentResourceId.
        The `OCID`__ of the VM cluster.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The vm_cluster_id of this DbHomeFromAgentResourceId.
        :rtype: str
        """
        return self._vm_cluster_id

    @vm_cluster_id.setter
    def vm_cluster_id(self, vm_cluster_id):
        """
        Sets the vm_cluster_id of this DbHomeFromAgentResourceId.
        The `OCID`__ of the VM cluster.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param vm_cluster_id: The vm_cluster_id of this DbHomeFromAgentResourceId.
        :type: str
        """
        self._vm_cluster_id = vm_cluster_id

    @property
    def db_version(self):
        """
        **[Required]** Gets the db_version of this DbHomeFromAgentResourceId.
        The Oracle Database version.


        :return: The db_version of this DbHomeFromAgentResourceId.
        :rtype: str
        """
        return self._db_version

    @db_version.setter
    def db_version(self, db_version):
        """
        Sets the db_version of this DbHomeFromAgentResourceId.
        The Oracle Database version.


        :param db_version: The db_version of this DbHomeFromAgentResourceId.
        :type: str
        """
        self._db_version = db_version

    @property
    def db_home_location(self):
        """
        **[Required]** Gets the db_home_location of this DbHomeFromAgentResourceId.
        The location of the Oracle Database Home.


        :return: The db_home_location of this DbHomeFromAgentResourceId.
        :rtype: str
        """
        return self._db_home_location

    @db_home_location.setter
    def db_home_location(self, db_home_location):
        """
        Sets the db_home_location of this DbHomeFromAgentResourceId.
        The location of the Oracle Database Home.


        :param db_home_location: The db_home_location of this DbHomeFromAgentResourceId.
        :type: str
        """
        self._db_home_location = db_home_location

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this DbHomeFromAgentResourceId.
        Additional information about the current lifecycle state.


        :return: The lifecycle_details of this DbHomeFromAgentResourceId.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this DbHomeFromAgentResourceId.
        Additional information about the current lifecycle state.


        :param lifecycle_details: The lifecycle_details of this DbHomeFromAgentResourceId.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def time_created(self):
        """
        Gets the time_created of this DbHomeFromAgentResourceId.
        The date and time the Database Home was created.


        :return: The time_created of this DbHomeFromAgentResourceId.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DbHomeFromAgentResourceId.
        The date and time the Database Home was created.


        :param time_created: The time_created of this DbHomeFromAgentResourceId.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def kms_key_id(self):
        """
        Gets the kms_key_id of this DbHomeFromAgentResourceId.
        The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.


        :return: The kms_key_id of this DbHomeFromAgentResourceId.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this DbHomeFromAgentResourceId.
        The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.


        :param kms_key_id: The kms_key_id of this DbHomeFromAgentResourceId.
        :type: str
        """
        self._kms_key_id = kms_key_id

    @property
    def one_off_patches(self):
        """
        Gets the one_off_patches of this DbHomeFromAgentResourceId.
        List of one-off patches for Database Homes.


        :return: The one_off_patches of this DbHomeFromAgentResourceId.
        :rtype: list[str]
        """
        return self._one_off_patches

    @one_off_patches.setter
    def one_off_patches(self, one_off_patches):
        """
        Sets the one_off_patches of this DbHomeFromAgentResourceId.
        List of one-off patches for Database Homes.


        :param one_off_patches: The one_off_patches of this DbHomeFromAgentResourceId.
        :type: list[str]
        """
        self._one_off_patches = one_off_patches

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DbHomeFromAgentResourceId.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this DbHomeFromAgentResourceId.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DbHomeFromAgentResourceId.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this DbHomeFromAgentResourceId.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DbHomeFromAgentResourceId.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this DbHomeFromAgentResourceId.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DbHomeFromAgentResourceId.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this DbHomeFromAgentResourceId.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def database_software_image_id(self):
        """
        Gets the database_software_image_id of this DbHomeFromAgentResourceId.
        The database software image `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The database_software_image_id of this DbHomeFromAgentResourceId.
        :rtype: str
        """
        return self._database_software_image_id

    @database_software_image_id.setter
    def database_software_image_id(self, database_software_image_id):
        """
        Sets the database_software_image_id of this DbHomeFromAgentResourceId.
        The database software image `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param database_software_image_id: The database_software_image_id of this DbHomeFromAgentResourceId.
        :type: str
        """
        self._database_software_image_id = database_software_image_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .connection import Connection
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConnectionFromBICC(Connection):
    """
    The connection details for an Oracle Database data asset.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ConnectionFromBICC object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.ConnectionFromBICC.model_type` attribute
        of this class is ``BICC_CONNECTION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this ConnectionFromBICC.
            Allowed values for this property are: "ORACLE_ADWC_CONNECTION", "ORACLE_ATP_CONNECTION", "ORACLE_OBJECT_STORAGE_CONNECTION", "ORACLEDB_CONNECTION", "MYSQL_CONNECTION", "GENERIC_JDBC_CONNECTION", "BICC_CONNECTION", "AMAZON_S3_CONNECTION"
        :type model_type: str

        :param key:
            The value to assign to the key property of this ConnectionFromBICC.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this ConnectionFromBICC.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this ConnectionFromBICC.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this ConnectionFromBICC.
        :type name: str

        :param description:
            The value to assign to the description property of this ConnectionFromBICC.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this ConnectionFromBICC.
        :type object_version: int

        :param object_status:
            The value to assign to the object_status property of this ConnectionFromBICC.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this ConnectionFromBICC.
        :type identifier: str

        :param primary_schema:
            The value to assign to the primary_schema property of this ConnectionFromBICC.
        :type primary_schema: oci.data_integration.models.Schema

        :param connection_properties:
            The value to assign to the connection_properties property of this ConnectionFromBICC.
        :type connection_properties: list[oci.data_integration.models.ConnectionProperty]

        :param is_default:
            The value to assign to the is_default property of this ConnectionFromBICC.
        :type is_default: bool

        :param metadata:
            The value to assign to the metadata property of this ConnectionFromBICC.
        :type metadata: oci.data_integration.models.ObjectMetadata

        :param key_map:
            The value to assign to the key_map property of this ConnectionFromBICC.
        :type key_map: dict(str, str)

        :param username:
            The value to assign to the username property of this ConnectionFromBICC.
        :type username: str

        :param password_secret:
            The value to assign to the password_secret property of this ConnectionFromBICC.
        :type password_secret: oci.data_integration.models.SensitiveAttribute

        :param default_external_storage:
            The value to assign to the default_external_storage property of this ConnectionFromBICC.
        :type default_external_storage: oci.data_integration.models.ExternalStorage

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'object_status': 'int',
            'identifier': 'str',
            'primary_schema': 'Schema',
            'connection_properties': 'list[ConnectionProperty]',
            'is_default': 'bool',
            'metadata': 'ObjectMetadata',
            'key_map': 'dict(str, str)',
            'username': 'str',
            'password_secret': 'SensitiveAttribute',
            'default_external_storage': 'ExternalStorage'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'primary_schema': 'primarySchema',
            'connection_properties': 'connectionProperties',
            'is_default': 'isDefault',
            'metadata': 'metadata',
            'key_map': 'keyMap',
            'username': 'username',
            'password_secret': 'passwordSecret',
            'default_external_storage': 'defaultExternalStorage'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._object_status = None
        self._identifier = None
        self._primary_schema = None
        self._connection_properties = None
        self._is_default = None
        self._metadata = None
        self._key_map = None
        self._username = None
        self._password_secret = None
        self._default_external_storage = None
        self._model_type = 'BICC_CONNECTION'

    @property
    def username(self):
        """
        Gets the username of this ConnectionFromBICC.
        The user name for the connection.


        :return: The username of this ConnectionFromBICC.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """
        Sets the username of this ConnectionFromBICC.
        The user name for the connection.


        :param username: The username of this ConnectionFromBICC.
        :type: str
        """
        self._username = username

    @property
    def password_secret(self):
        """
        Gets the password_secret of this ConnectionFromBICC.

        :return: The password_secret of this ConnectionFromBICC.
        :rtype: oci.data_integration.models.SensitiveAttribute
        """
        return self._password_secret

    @password_secret.setter
    def password_secret(self, password_secret):
        """
        Sets the password_secret of this ConnectionFromBICC.

        :param password_secret: The password_secret of this ConnectionFromBICC.
        :type: oci.data_integration.models.SensitiveAttribute
        """
        self._password_secret = password_secret

    @property
    def default_external_storage(self):
        """
        Gets the default_external_storage of this ConnectionFromBICC.

        :return: The default_external_storage of this ConnectionFromBICC.
        :rtype: oci.data_integration.models.ExternalStorage
        """
        return self._default_external_storage

    @default_external_storage.setter
    def default_external_storage(self, default_external_storage):
        """
        Sets the default_external_storage of this ConnectionFromBICC.

        :param default_external_storage: The default_external_storage of this ConnectionFromBICC.
        :type: oci.data_integration.models.ExternalStorage
        """
        self._default_external_storage = default_external_storage

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateScriptDetails(object):
    """
    Details of the request body used to update a script.
    Only Side or JavaScript content types are supported and content should be in Side or JavaScript formats only.
    """

    #: A constant which can be used with the content_type property of a UpdateScriptDetails.
    #: This constant has a value of "SIDE"
    CONTENT_TYPE_SIDE = "SIDE"

    #: A constant which can be used with the content_type property of a UpdateScriptDetails.
    #: This constant has a value of "JS"
    CONTENT_TYPE_JS = "JS"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateScriptDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateScriptDetails.
        :type display_name: str

        :param content_type:
            The value to assign to the content_type property of this UpdateScriptDetails.
            Allowed values for this property are: "SIDE", "JS"
        :type content_type: str

        :param content:
            The value to assign to the content property of this UpdateScriptDetails.
        :type content: str

        :param content_file_name:
            The value to assign to the content_file_name property of this UpdateScriptDetails.
        :type content_file_name: str

        :param parameters:
            The value to assign to the parameters property of this UpdateScriptDetails.
        :type parameters: list[oci.apm_synthetics.models.ScriptParameter]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateScriptDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateScriptDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'content_type': 'str',
            'content': 'str',
            'content_file_name': 'str',
            'parameters': 'list[ScriptParameter]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'content_type': 'contentType',
            'content': 'content',
            'content_file_name': 'contentFileName',
            'parameters': 'parameters',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._content_type = None
        self._content = None
        self._content_file_name = None
        self._parameters = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateScriptDetails.
        Unique name that can be edited. The name should not contain any confidential information.


        :return: The display_name of this UpdateScriptDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateScriptDetails.
        Unique name that can be edited. The name should not contain any confidential information.


        :param display_name: The display_name of this UpdateScriptDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def content_type(self):
        """
        Gets the content_type of this UpdateScriptDetails.
        Content type of script.

        Allowed values for this property are: "SIDE", "JS"


        :return: The content_type of this UpdateScriptDetails.
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """
        Sets the content_type of this UpdateScriptDetails.
        Content type of script.


        :param content_type: The content_type of this UpdateScriptDetails.
        :type: str
        """
        allowed_values = ["SIDE", "JS"]
        if not value_allowed_none_or_none_sentinel(content_type, allowed_values):
            raise ValueError(
                "Invalid value for `content_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._content_type = content_type

    @property
    def content(self):
        """
        Gets the content of this UpdateScriptDetails.
        The content of the script. It may contain custom-defined tags that can be used for setting dynamic parameters.
        The format to set dynamic parameters is: `<ORAP><ON>param name</ON><OV>param value</OV><OS>isParamValueSecret(true/false)</OS></ORAP>`.
        Param value and isParamValueSecret are optional, the default value for isParamValueSecret is false.
        Examples:
        With mandatory param name : `<ORAP><ON>param name</ON></ORAP>`
        With parameter name and value : `<ORAP><ON>param name</ON><OV>param value</OV></ORAP>`
        Note that the content is valid if it matches the given content type. For example, if the content type is SIDE, then the content should be in Side script format. If the content type is JS, then the content should be in JavaScript format.


        :return: The content of this UpdateScriptDetails.
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """
        Sets the content of this UpdateScriptDetails.
        The content of the script. It may contain custom-defined tags that can be used for setting dynamic parameters.
        The format to set dynamic parameters is: `<ORAP><ON>param name</ON><OV>param value</OV><OS>isParamValueSecret(true/false)</OS></ORAP>`.
        Param value and isParamValueSecret are optional, the default value for isParamValueSecret is false.
        Examples:
        With mandatory param name : `<ORAP><ON>param name</ON></ORAP>`
        With parameter name and value : `<ORAP><ON>param name</ON><OV>param value</OV></ORAP>`
        Note that the content is valid if it matches the given content type. For example, if the content type is SIDE, then the content should be in Side script format. If the content type is JS, then the content should be in JavaScript format.


        :param content: The content of this UpdateScriptDetails.
        :type: str
        """
        self._content = content

    @property
    def content_file_name(self):
        """
        Gets the content_file_name of this UpdateScriptDetails.
        File name of uploaded script content.


        :return: The content_file_name of this UpdateScriptDetails.
        :rtype: str
        """
        return self._content_file_name

    @content_file_name.setter
    def content_file_name(self, content_file_name):
        """
        Sets the content_file_name of this UpdateScriptDetails.
        File name of uploaded script content.


        :param content_file_name: The content_file_name of this UpdateScriptDetails.
        :type: str
        """
        self._content_file_name = content_file_name

    @property
    def parameters(self):
        """
        Gets the parameters of this UpdateScriptDetails.
        List of script parameters. Example: `[{\"paramName\": \"userid\", \"paramValue\":\"testuser\", \"isSecret\": false}]`


        :return: The parameters of this UpdateScriptDetails.
        :rtype: list[oci.apm_synthetics.models.ScriptParameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this UpdateScriptDetails.
        List of script parameters. Example: `[{\"paramName\": \"userid\", \"paramValue\":\"testuser\", \"isSecret\": false}]`


        :param parameters: The parameters of this UpdateScriptDetails.
        :type: list[oci.apm_synthetics.models.ScriptParameter]
        """
        self._parameters = parameters

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateScriptDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this UpdateScriptDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateScriptDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this UpdateScriptDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateScriptDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this UpdateScriptDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateScriptDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this UpdateScriptDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateAutonomousVmClusterDetails(object):
    """
    Details for the create Autonomous VM cluster operation.
    """

    #: A constant which can be used with the license_model property of a CreateAutonomousVmClusterDetails.
    #: This constant has a value of "LICENSE_INCLUDED"
    LICENSE_MODEL_LICENSE_INCLUDED = "LICENSE_INCLUDED"

    #: A constant which can be used with the license_model property of a CreateAutonomousVmClusterDetails.
    #: This constant has a value of "BRING_YOUR_OWN_LICENSE"
    LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = "BRING_YOUR_OWN_LICENSE"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateAutonomousVmClusterDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateAutonomousVmClusterDetails.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this CreateAutonomousVmClusterDetails.
        :type display_name: str

        :param exadata_infrastructure_id:
            The value to assign to the exadata_infrastructure_id property of this CreateAutonomousVmClusterDetails.
        :type exadata_infrastructure_id: str

        :param vm_cluster_network_id:
            The value to assign to the vm_cluster_network_id property of this CreateAutonomousVmClusterDetails.
        :type vm_cluster_network_id: str

        :param time_zone:
            The value to assign to the time_zone property of this CreateAutonomousVmClusterDetails.
        :type time_zone: str

        :param is_local_backup_enabled:
            The value to assign to the is_local_backup_enabled property of this CreateAutonomousVmClusterDetails.
        :type is_local_backup_enabled: bool

        :param license_model:
            The value to assign to the license_model property of this CreateAutonomousVmClusterDetails.
            Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"
        :type license_model: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateAutonomousVmClusterDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateAutonomousVmClusterDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'display_name': 'str',
            'exadata_infrastructure_id': 'str',
            'vm_cluster_network_id': 'str',
            'time_zone': 'str',
            'is_local_backup_enabled': 'bool',
            'license_model': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'exadata_infrastructure_id': 'exadataInfrastructureId',
            'vm_cluster_network_id': 'vmClusterNetworkId',
            'time_zone': 'timeZone',
            'is_local_backup_enabled': 'isLocalBackupEnabled',
            'license_model': 'licenseModel',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._compartment_id = None
        self._display_name = None
        self._exadata_infrastructure_id = None
        self._vm_cluster_network_id = None
        self._time_zone = None
        self._is_local_backup_enabled = None
        self._license_model = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateAutonomousVmClusterDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateAutonomousVmClusterDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateAutonomousVmClusterDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateAutonomousVmClusterDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateAutonomousVmClusterDetails.
        The user-friendly name for the Autonomous VM cluster. The name does not need to be unique.


        :return: The display_name of this CreateAutonomousVmClusterDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateAutonomousVmClusterDetails.
        The user-friendly name for the Autonomous VM cluster. The name does not need to be unique.


        :param display_name: The display_name of this CreateAutonomousVmClusterDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def exadata_infrastructure_id(self):
        """
        **[Required]** Gets the exadata_infrastructure_id of this CreateAutonomousVmClusterDetails.
        The `OCID`__ of the Exadata infrastructure.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The exadata_infrastructure_id of this CreateAutonomousVmClusterDetails.
        :rtype: str
        """
        return self._exadata_infrastructure_id

    @exadata_infrastructure_id.setter
    def exadata_infrastructure_id(self, exadata_infrastructure_id):
        """
        Sets the exadata_infrastructure_id of this CreateAutonomousVmClusterDetails.
        The `OCID`__ of the Exadata infrastructure.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param exadata_infrastructure_id: The exadata_infrastructure_id of this CreateAutonomousVmClusterDetails.
        :type: str
        """
        self._exadata_infrastructure_id = exadata_infrastructure_id

    @property
    def vm_cluster_network_id(self):
        """
        **[Required]** Gets the vm_cluster_network_id of this CreateAutonomousVmClusterDetails.
        The `OCID`__ of the VM cluster network.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The vm_cluster_network_id of this CreateAutonomousVmClusterDetails.
        :rtype: str
        """
        return self._vm_cluster_network_id

    @vm_cluster_network_id.setter
    def vm_cluster_network_id(self, vm_cluster_network_id):
        """
        Sets the vm_cluster_network_id of this CreateAutonomousVmClusterDetails.
        The `OCID`__ of the VM cluster network.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param vm_cluster_network_id: The vm_cluster_network_id of this CreateAutonomousVmClusterDetails.
        :type: str
        """
        self._vm_cluster_network_id = vm_cluster_network_id

    @property
    def time_zone(self):
        """
        Gets the time_zone of this CreateAutonomousVmClusterDetails.
        The time zone to use for the Autonomous VM cluster. For details, see `DB System Time Zones`__.

        __ https://docs.cloud.oracle.com/Content/Database/References/timezones.htm


        :return: The time_zone of this CreateAutonomousVmClusterDetails.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this CreateAutonomousVmClusterDetails.
        The time zone to use for the Autonomous VM cluster. For details, see `DB System Time Zones`__.

        __ https://docs.cloud.oracle.com/Content/Database/References/timezones.htm


        :param time_zone: The time_zone of this CreateAutonomousVmClusterDetails.
        :type: str
        """
        self._time_zone = time_zone

    @property
    def is_local_backup_enabled(self):
        """
        Gets the is_local_backup_enabled of this CreateAutonomousVmClusterDetails.
        If true, database backup on local Exadata storage is configured for the Autonomous VM cluster. If false, database backup on local Exadata storage is not available in the Autonomous VM cluster.


        :return: The is_local_backup_enabled of this CreateAutonomousVmClusterDetails.
        :rtype: bool
        """
        return self._is_local_backup_enabled

    @is_local_backup_enabled.setter
    def is_local_backup_enabled(self, is_local_backup_enabled):
        """
        Sets the is_local_backup_enabled of this CreateAutonomousVmClusterDetails.
        If true, database backup on local Exadata storage is configured for the Autonomous VM cluster. If false, database backup on local Exadata storage is not available in the Autonomous VM cluster.


        :param is_local_backup_enabled: The is_local_backup_enabled of this CreateAutonomousVmClusterDetails.
        :type: bool
        """
        self._is_local_backup_enabled = is_local_backup_enabled

    @property
    def license_model(self):
        """
        Gets the license_model of this CreateAutonomousVmClusterDetails.
        The Oracle license model that applies to the Autonomous VM cluster. The default is BRING_YOUR_OWN_LICENSE.

        Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"


        :return: The license_model of this CreateAutonomousVmClusterDetails.
        :rtype: str
        """
        return self._license_model

    @license_model.setter
    def license_model(self, license_model):
        """
        Sets the license_model of this CreateAutonomousVmClusterDetails.
        The Oracle license model that applies to the Autonomous VM cluster. The default is BRING_YOUR_OWN_LICENSE.


        :param license_model: The license_model of this CreateAutonomousVmClusterDetails.
        :type: str
        """
        allowed_values = ["LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"]
        if not value_allowed_none_or_none_sentinel(license_model, allowed_values):
            raise ValueError(
                "Invalid value for `license_model`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._license_model = license_model

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateAutonomousVmClusterDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateAutonomousVmClusterDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateAutonomousVmClusterDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateAutonomousVmClusterDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateAutonomousVmClusterDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateAutonomousVmClusterDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateAutonomousVmClusterDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateAutonomousVmClusterDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateMultipartUploadDetails(object):
    """
    To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized,
    talk to an administrator. If you are an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the storage_tier property of a CreateMultipartUploadDetails.
    #: This constant has a value of "Standard"
    STORAGE_TIER_STANDARD = "Standard"

    #: A constant which can be used with the storage_tier property of a CreateMultipartUploadDetails.
    #: This constant has a value of "InfrequentAccess"
    STORAGE_TIER_INFREQUENT_ACCESS = "InfrequentAccess"

    #: A constant which can be used with the storage_tier property of a CreateMultipartUploadDetails.
    #: This constant has a value of "Archive"
    STORAGE_TIER_ARCHIVE = "Archive"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateMultipartUploadDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param object:
            The value to assign to the object property of this CreateMultipartUploadDetails.
        :type object: str

        :param content_type:
            The value to assign to the content_type property of this CreateMultipartUploadDetails.
        :type content_type: str

        :param content_language:
            The value to assign to the content_language property of this CreateMultipartUploadDetails.
        :type content_language: str

        :param content_encoding:
            The value to assign to the content_encoding property of this CreateMultipartUploadDetails.
        :type content_encoding: str

        :param content_disposition:
            The value to assign to the content_disposition property of this CreateMultipartUploadDetails.
        :type content_disposition: str

        :param cache_control:
            The value to assign to the cache_control property of this CreateMultipartUploadDetails.
        :type cache_control: str

        :param storage_tier:
            The value to assign to the storage_tier property of this CreateMultipartUploadDetails.
            Allowed values for this property are: "Standard", "InfrequentAccess", "Archive"
        :type storage_tier: str

        :param metadata:
            The value to assign to the metadata property of this CreateMultipartUploadDetails.
        :type metadata: dict(str, str)

        """
        self.swagger_types = {
            'object': 'str',
            'content_type': 'str',
            'content_language': 'str',
            'content_encoding': 'str',
            'content_disposition': 'str',
            'cache_control': 'str',
            'storage_tier': 'str',
            'metadata': 'dict(str, str)'
        }

        self.attribute_map = {
            'object': 'object',
            'content_type': 'contentType',
            'content_language': 'contentLanguage',
            'content_encoding': 'contentEncoding',
            'content_disposition': 'contentDisposition',
            'cache_control': 'cacheControl',
            'storage_tier': 'storageTier',
            'metadata': 'metadata'
        }

        self._object = None
        self._content_type = None
        self._content_language = None
        self._content_encoding = None
        self._content_disposition = None
        self._cache_control = None
        self._storage_tier = None
        self._metadata = None

    @property
    def object(self):
        """
        **[Required]** Gets the object of this CreateMultipartUploadDetails.
        The name of the object to which this multi-part upload is targeted. Avoid entering confidential information.
        Example: test/object1.log


        :return: The object of this CreateMultipartUploadDetails.
        :rtype: str
        """
        return self._object

    @object.setter
    def object(self, object):
        """
        Sets the object of this CreateMultipartUploadDetails.
        The name of the object to which this multi-part upload is targeted. Avoid entering confidential information.
        Example: test/object1.log


        :param object: The object of this CreateMultipartUploadDetails.
        :type: str
        """
        self._object = object

    @property
    def content_type(self):
        """
        Gets the content_type of this CreateMultipartUploadDetails.
        The optional Content-Type header that defines the standard MIME type format of the object to upload.
        Specifying values for this header has no effect on Object Storage behavior. Programs that read the object
        determine what to do based on the value provided. For example, you could use this header to identify and
        perform special operations on text only objects.


        :return: The content_type of this CreateMultipartUploadDetails.
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """
        Sets the content_type of this CreateMultipartUploadDetails.
        The optional Content-Type header that defines the standard MIME type format of the object to upload.
        Specifying values for this header has no effect on Object Storage behavior. Programs that read the object
        determine what to do based on the value provided. For example, you could use this header to identify and
        perform special operations on text only objects.


        :param content_type: The content_type of this CreateMultipartUploadDetails.
        :type: str
        """
        self._content_type = content_type

    @property
    def content_language(self):
        """
        Gets the content_language of this CreateMultipartUploadDetails.
        The optional Content-Language header that defines the content language of the object to upload. Specifying
        values for this header has no effect on Object Storage behavior. Programs that read the object determine what
        to do based on the value provided. For example, you could use this header to identify and differentiate objects
        based on a particular language.


        :return: The content_language of this CreateMultipartUploadDetails.
        :rtype: str
        """
        return self._content_language

    @content_language.setter
    def content_language(self, content_language):
        """
        Sets the content_language of this CreateMultipartUploadDetails.
        The optional Content-Language header that defines the content language of the object to upload. Specifying
        values for this header has no effect on Object Storage behavior. Programs that read the object determine what
        to do based on the value provided. For example, you could use this header to identify and differentiate objects
        based on a particular language.


        :param content_language: The content_language of this CreateMultipartUploadDetails.
        :type: str
        """
        self._content_language = content_language

    @property
    def content_encoding(self):
        """
        Gets the content_encoding of this CreateMultipartUploadDetails.
        The optional Content-Encoding header that defines the content encodings that were applied to the object to
        upload. Specifying values for this header has no effect on Object Storage behavior. Programs that read the
        object determine what to do based on the value provided. For example, you could use this header to determine
        what decoding mechanisms need to be applied to obtain the media-type specified by the Content-Type header of
        the object.


        :return: The content_encoding of this CreateMultipartUploadDetails.
        :rtype: str
        """
        return self._content_encoding

    @content_encoding.setter
    def content_encoding(self, content_encoding):
        """
        Sets the content_encoding of this CreateMultipartUploadDetails.
        The optional Content-Encoding header that defines the content encodings that were applied to the object to
        upload. Specifying values for this header has no effect on Object Storage behavior. Programs that read the
        object determine what to do based on the value provided. For example, you could use this header to determine
        what decoding mechanisms need to be applied to obtain the media-type specified by the Content-Type header of
        the object.


        :param content_encoding: The content_encoding of this CreateMultipartUploadDetails.
        :type: str
        """
        self._content_encoding = content_encoding

    @property
    def content_disposition(self):
        """
        Gets the content_disposition of this CreateMultipartUploadDetails.
        The optional Content-Disposition header that defines presentational information for the object to be
        returned in GetObject and HeadObject responses. Specifying values for this header has no effect on Object
        Storage behavior. Programs that read the object determine what to do based on the value provided.
        For example, you could use this header to let users download objects with custom filenames in a browser.


        :return: The content_disposition of this CreateMultipartUploadDetails.
        :rtype: str
        """
        return self._content_disposition

    @content_disposition.setter
    def content_disposition(self, content_disposition):
        """
        Sets the content_disposition of this CreateMultipartUploadDetails.
        The optional Content-Disposition header that defines presentational information for the object to be
        returned in GetObject and HeadObject responses. Specifying values for this header has no effect on Object
        Storage behavior. Programs that read the object determine what to do based on the value provided.
        For example, you could use this header to let users download objects with custom filenames in a browser.


        :param content_disposition: The content_disposition of this CreateMultipartUploadDetails.
        :type: str
        """
        self._content_disposition = content_disposition

    @property
    def cache_control(self):
        """
        Gets the cache_control of this CreateMultipartUploadDetails.
        The optional Cache-Control header that defines the caching behavior value to be returned in GetObject and
        HeadObject responses. Specifying values for this header has no effect on Object Storage behavior. Programs
        that read the object determine what to do based on the value provided.
        For example, you could use this header to identify objects that require caching restrictions.


        :return: The cache_control of this CreateMultipartUploadDetails.
        :rtype: str
        """
        return self._cache_control

    @cache_control.setter
    def cache_control(self, cache_control):
        """
        Sets the cache_control of this CreateMultipartUploadDetails.
        The optional Cache-Control header that defines the caching behavior value to be returned in GetObject and
        HeadObject responses. Specifying values for this header has no effect on Object Storage behavior. Programs
        that read the object determine what to do based on the value provided.
        For example, you could use this header to identify objects that require caching restrictions.


        :param cache_control: The cache_control of this CreateMultipartUploadDetails.
        :type: str
        """
        self._cache_control = cache_control

    @property
    def storage_tier(self):
        """
        Gets the storage_tier of this CreateMultipartUploadDetails.
        The storage tier that the object should be stored in. If not specified, the object will be stored in
        the same storage tier as the bucket.

        Allowed values for this property are: "Standard", "InfrequentAccess", "Archive"


        :return: The storage_tier of this CreateMultipartUploadDetails.
        :rtype: str
        """
        return self._storage_tier

    @storage_tier.setter
    def storage_tier(self, storage_tier):
        """
        Sets the storage_tier of this CreateMultipartUploadDetails.
        The storage tier that the object should be stored in. If not specified, the object will be stored in
        the same storage tier as the bucket.


        :param storage_tier: The storage_tier of this CreateMultipartUploadDetails.
        :type: str
        """
        allowed_values = ["Standard", "InfrequentAccess", "Archive"]
        if not value_allowed_none_or_none_sentinel(storage_tier, allowed_values):
            raise ValueError(
                "Invalid value for `storage_tier`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._storage_tier = storage_tier

    @property
    def metadata(self):
        """
        Gets the metadata of this CreateMultipartUploadDetails.
        Arbitrary string keys and values for the user-defined metadata for the object.
        Keys must be in \"opc-meta-*\" format. Avoid entering confidential information.


        :return: The metadata of this CreateMultipartUploadDetails.
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this CreateMultipartUploadDetails.
        Arbitrary string keys and values for the user-defined metadata for the object.
        Keys must be in \"opc-meta-*\" format. Avoid entering confidential information.


        :param metadata: The metadata of this CreateMultipartUploadDetails.
        :type: dict(str, str)
        """
        self._metadata = metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExportedKeyData(object):
    """
    The response to a request to export key material.
    """

    #: A constant which can be used with the algorithm property of a ExportedKeyData.
    #: This constant has a value of "RSA_OAEP_AES_SHA256"
    ALGORITHM_RSA_OAEP_AES_SHA256 = "RSA_OAEP_AES_SHA256"

    #: A constant which can be used with the algorithm property of a ExportedKeyData.
    #: This constant has a value of "RSA_OAEP_SHA256"
    ALGORITHM_RSA_OAEP_SHA256 = "RSA_OAEP_SHA256"

    def __init__(self, **kwargs):
        """
        Initializes a new ExportedKeyData object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key_version_id:
            The value to assign to the key_version_id property of this ExportedKeyData.
        :type key_version_id: str

        :param key_id:
            The value to assign to the key_id property of this ExportedKeyData.
        :type key_id: str

        :param time_created:
            The value to assign to the time_created property of this ExportedKeyData.
        :type time_created: datetime

        :param vault_id:
            The value to assign to the vault_id property of this ExportedKeyData.
        :type vault_id: str

        :param encrypted_key:
            The value to assign to the encrypted_key property of this ExportedKeyData.
        :type encrypted_key: str

        :param algorithm:
            The value to assign to the algorithm property of this ExportedKeyData.
            Allowed values for this property are: "RSA_OAEP_AES_SHA256", "RSA_OAEP_SHA256", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type algorithm: str

        """
        self.swagger_types = {
            'key_version_id': 'str',
            'key_id': 'str',
            'time_created': 'datetime',
            'vault_id': 'str',
            'encrypted_key': 'str',
            'algorithm': 'str'
        }

        self.attribute_map = {
            'key_version_id': 'keyVersionId',
            'key_id': 'keyId',
            'time_created': 'timeCreated',
            'vault_id': 'vaultId',
            'encrypted_key': 'encryptedKey',
            'algorithm': 'algorithm'
        }

        self._key_version_id = None
        self._key_id = None
        self._time_created = None
        self._vault_id = None
        self._encrypted_key = None
        self._algorithm = None

    @property
    def key_version_id(self):
        """
        **[Required]** Gets the key_version_id of this ExportedKeyData.
        The OCID of the key version.


        :return: The key_version_id of this ExportedKeyData.
        :rtype: str
        """
        return self._key_version_id

    @key_version_id.setter
    def key_version_id(self, key_version_id):
        """
        Sets the key_version_id of this ExportedKeyData.
        The OCID of the key version.


        :param key_version_id: The key_version_id of this ExportedKeyData.
        :type: str
        """
        self._key_version_id = key_version_id

    @property
    def key_id(self):
        """
        **[Required]** Gets the key_id of this ExportedKeyData.
        The OCID of the master encryption key associated with this key version.


        :return: The key_id of this ExportedKeyData.
        :rtype: str
        """
        return self._key_id

    @key_id.setter
    def key_id(self, key_id):
        """
        Sets the key_id of this ExportedKeyData.
        The OCID of the master encryption key associated with this key version.


        :param key_id: The key_id of this ExportedKeyData.
        :type: str
        """
        self._key_id = key_id

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ExportedKeyData.
        The date and time this key version was created, expressed in `RFC 3339`__ timestamp format.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this ExportedKeyData.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ExportedKeyData.
        The date and time this key version was created, expressed in `RFC 3339`__ timestamp format.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this ExportedKeyData.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def vault_id(self):
        """
        **[Required]** Gets the vault_id of this ExportedKeyData.
        The OCID of the vault that contains this key version.


        :return: The vault_id of this ExportedKeyData.
        :rtype: str
        """
        return self._vault_id

    @vault_id.setter
    def vault_id(self, vault_id):
        """
        Sets the vault_id of this ExportedKeyData.
        The OCID of the vault that contains this key version.


        :param vault_id: The vault_id of this ExportedKeyData.
        :type: str
        """
        self._vault_id = vault_id

    @property
    def encrypted_key(self):
        """
        **[Required]** Gets the encrypted_key of this ExportedKeyData.
        The base64-encoded exported key material, which is encrypted by using the public RSA wrapping key specified in the export request.


        :return: The encrypted_key of this ExportedKeyData.
        :rtype: str
        """
        return self._encrypted_key

    @encrypted_key.setter
    def encrypted_key(self, encrypted_key):
        """
        Sets the encrypted_key of this ExportedKeyData.
        The base64-encoded exported key material, which is encrypted by using the public RSA wrapping key specified in the export request.


        :param encrypted_key: The encrypted_key of this ExportedKeyData.
        :type: str
        """
        self._encrypted_key = encrypted_key

    @property
    def algorithm(self):
        """
        **[Required]** Gets the algorithm of this ExportedKeyData.
        The encryption algorithm to use to encrypt exportable key material from a key that persists on the server (as opposed to a key that
        persists on a hardware security module and, therefore, cannot be exported). Specifying RSA_OAEP_AES_SHA256 invokes the RSA AES key
        wrap mechanism, which generates a temporary AES key. The temporary AES key is wrapped by the RSA public wrapping key provided along
        with the request, creating a wrapped temporary AES key. The temporary AES key is also used to wrap the exportable key material. The
        wrapped temporary AES key and the wrapped exportable key material are concatenated, producing concatenated blob output that jointly
        represents them. Specifying RSA_OAEP_SHA256 means that the exportable key material is wrapped by the RSA public wrapping key provided
        along with the request.

        Allowed values for this property are: "RSA_OAEP_AES_SHA256", "RSA_OAEP_SHA256", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The algorithm of this ExportedKeyData.
        :rtype: str
        """
        return self._algorithm

    @algorithm.setter
    def algorithm(self, algorithm):
        """
        Sets the algorithm of this ExportedKeyData.
        The encryption algorithm to use to encrypt exportable key material from a key that persists on the server (as opposed to a key that
        persists on a hardware security module and, therefore, cannot be exported). Specifying RSA_OAEP_AES_SHA256 invokes the RSA AES key
        wrap mechanism, which generates a temporary AES key. The temporary AES key is wrapped by the RSA public wrapping key provided along
        with the request, creating a wrapped temporary AES key. The temporary AES key is also used to wrap the exportable key material. The
        wrapped temporary AES key and the wrapped exportable key material are concatenated, producing concatenated blob output that jointly
        represents them. Specifying RSA_OAEP_SHA256 means that the exportable key material is wrapped by the RSA public wrapping key provided
        along with the request.


        :param algorithm: The algorithm of this ExportedKeyData.
        :type: str
        """
        allowed_values = ["RSA_OAEP_AES_SHA256", "RSA_OAEP_SHA256"]
        if not value_allowed_none_or_none_sentinel(algorithm, allowed_values):
            algorithm = 'UNKNOWN_ENUM_VALUE'
        self._algorithm = algorithm

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SearchResultSummary(object):
    """
    Summary of results.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SearchResultSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param result_count:
            The value to assign to the result_count property of this SearchResultSummary.
        :type result_count: int

        :param field_count:
            The value to assign to the field_count property of this SearchResultSummary.
        :type field_count: int

        """
        self.swagger_types = {
            'result_count': 'int',
            'field_count': 'int'
        }

        self.attribute_map = {
            'result_count': 'resultCount',
            'field_count': 'fieldCount'
        }

        self._result_count = None
        self._field_count = None

    @property
    def result_count(self):
        """
        Gets the result_count of this SearchResultSummary.
        Total number of search results.


        :return: The result_count of this SearchResultSummary.
        :rtype: int
        """
        return self._result_count

    @result_count.setter
    def result_count(self, result_count):
        """
        Sets the result_count of this SearchResultSummary.
        Total number of search results.


        :param result_count: The result_count of this SearchResultSummary.
        :type: int
        """
        self._result_count = result_count

    @property
    def field_count(self):
        """
        Gets the field_count of this SearchResultSummary.
        Total number of field schema information.


        :return: The field_count of this SearchResultSummary.
        :rtype: int
        """
        return self._field_count

    @field_count.setter
    def field_count(self, field_count):
        """
        Sets the field_count of this SearchResultSummary.
        Total number of field schema information.


        :param field_count: The field_count of this SearchResultSummary.
        :type: int
        """
        self._field_count = field_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
